CmCredentialMetadata class

Credential fields returned by metadata-only enumeration.

Authenticators that do not support the extension may still return a standard publicKey. In that case metadataOnly is false and coseAlgorithm is read from the COSE key.

Annotations
  • @JsonSerializable.new(createFactory: false, explicitToJson: true)

Constructors

CmCredentialMetadata({required PublicKeyCredentialUserEntity user, required PublicKeyCredentialDescriptor credentialId, required int coseAlgorithm, required bool metadataOnly, CoseKey? publicKey, int? totalCredentials, required int credProtect, List<int>? largeBlobKey})

Properties

coseAlgorithm → int
final
credentialId → PublicKeyCredentialDescriptor
final
credProtect → int
final
hashCode → int
The hash code for this object.
no setterinherited
largeBlobKey → List<int>?
final
metadataOnly → bool
final
publicKey → CoseKey?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCredentials → int?
final
user → PublicKeyCredentialUserEntity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited