CmRp class

Annotations
  • @JsonSerializable.new(createFactory: false, explicitToJson: true)

Constructors

CmRp({required PublicKeyCredentialRpEntity rp, required List<int> rpIdHash, int? totalRPs})

Properties

hashCode → int
The hash code for this object.
no setterinherited
rp → PublicKeyCredentialRpEntity
final
rpIdHash → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalRPs → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited