CredentialManagement class

Constructors

CredentialManagement(Ctap2 _ctap, PinProtocol _pinProtocol, List<int> _pinToken)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteCredential(PublicKeyCredentialDescriptor credentialId) → Future<void>
enumerateCredentials(List<int> rpIdHash) → Future<List<CmCredential>>
enumerateCredentialsBegin(List<int> rpIdHash) → Future<CmCredential>
enumerateCredentialsGetNextCredential() → Future<CmCredential>
enumerateCredentialsMetadataOnly(List<int> rpIdHash) → Future<List<CmCredentialMetadata>>
Enumerates credentials without requesting their full public keys.
enumerateRPs() → Future<List<CmRp>>
enumerateRpsBegin() → Future<CmRp>
enumerateRpsGetNextRp() → Future<CmRp>
getMetadata() → Future<CmMetadata>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateUserInformation(PublicKeyCredentialDescriptor credentialId, PublicKeyCredentialUserEntity user) → Future<void>

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

isSupported(AuthenticatorInfo info) → bool
Returns true if the authenticator info supports the CredentialManagement command.