CredentialManagementResponse class

CTAP2 authenticatorCredentialManagement (0x0A) response (spec 6.8).

Returns RP/user/credential information, counts, and key material depending on the subCommand.

Annotations
  • @JsonSerializable.new(createFactory: false, explicitToJson: true)

Constructors

CredentialManagementResponse({int? existingResidentCredentialsCount, int? maxPossibleRemainingResidentCredentialsCount, PublicKeyCredentialRpEntity? rp, List<int>? rpIdHash, int? totalRPs, PublicKeyCredentialUserEntity? user, PublicKeyCredentialDescriptor? credentialId, CoseKey? publicKey, int? totalCredentials, int? credProtect, List<int>? largeBlobKey, int? coseAlgorithm})

Properties

coseAlgorithm → int?
COSE algorithm ID returned by the metadata-only extension.
final
credentialId → PublicKeyCredentialDescriptor?
Credential identifier.
final
credProtect → int?
Credential protection policy value.
final
existingResidentCredentialsCount → int?
Number of existing discoverable credentials on the authenticator.
final
hashCode → int
The hash code for this object.
no setterinherited
largeBlobKey → List<int>?
Large blob encryption key.
final
maxPossibleRemainingResidentCredentialsCount → int?
Maximum additional discoverable credentials possible.
final
publicKey → CoseKey?
Credential public key (COSE_Key).
final
rp → PublicKeyCredentialRpEntity?
Relying Party information.
final
rpIdHash → List<int>?
SHA-256 hash of the RP ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCredentials → int?
Total number of credentials for the RP.
final
totalRPs → int?
Total number of RPs present on the authenticator.
final
user → PublicKeyCredentialUserEntity?
User information.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

decode(List<int> data, {CoseConfiguration? configuration}) → CredentialManagementResponse
Decodes a CBOR-encoded response into CredentialManagementResponse.