Ctap2Commands enum
Values
- makeCredential → const Ctap2Commands
-
const Ctap2Commands(0x01) - getAssertion → const Ctap2Commands
-
const Ctap2Commands(0x02) - getInfo → const Ctap2Commands
-
const Ctap2Commands(0x04) - clientPIN → const Ctap2Commands
-
const Ctap2Commands(0x06) - reset → const Ctap2Commands
-
const Ctap2Commands(0x07) - getNextAssertion → const Ctap2Commands
-
const Ctap2Commands(0x08) - credentialManagement → const Ctap2Commands
-
const Ctap2Commands(0x0A) - selection → const Ctap2Commands
-
const Ctap2Commands(0x0B) - largeBlobs → const Ctap2Commands
-
const Ctap2Commands(0x0C) - config → const Ctap2Commands
-
const Ctap2Commands(0x0D)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Ctap2Commands> - A constant List of the values in this enum, in order of their declaration.