GetInfoRequest class

CTAP2 authenticatorGetInfo (0x04) request.

Requests the authenticator's capabilities and preferences. Takes no inputs.

Constructors

GetInfoRequest()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → List<int>
Encodes this request by returning the single command byte.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited