PublicKeyCredentialRpEntity class

WebAuthn Relying Party (RP) parameters used during credential creation (see spec 5.4.2). Contains the RP identifier.

Annotations
  • @JsonSerializable.new(createFactory: false)

Constructors

PublicKeyCredentialRpEntity({required String id})
PublicKeyCredentialRpEntity.fromCbor(Map cbor)
Parses from a CBOR map as used in CTAP requests.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
A unique identifier for the Relying Party entity; sets the RP ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCbor() → CborValue
Serializes this RP entity to a CBOR map for CTAP.
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited