SM2 class

Inheritance

Constructors

SM2(Map<int, dynamic> params, {required Sm2Configuration configuration})

Properties

algorithmId → int
no setterinherited
configuration → Sm2Configuration
final
entries → Iterable<MapEntry<int, dynamic>>
The map entries of this Map.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
Whether there is no key/value pair in the map.
no setterinherited
isNotEmpty → bool
Whether there is at least one key/value pair in the map.
no setterinherited
keys → Iterable<int>
The keys of this Map.
no setterinherited
length → int
The number of key/value pairs in the map.
no setterinherited
publicKeyBytes → List<int>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rustAlgorithm → String
no setteroverride
values → Iterable
The values of this Map.
no setterinherited

Methods

addAll(Map<int, dynamic> other) → void
Adds all key/value pairs of other to this map.
inherited
addEntries(Iterable<MapEntry<int, dynamic>> entries) → void
Adds all key/value pairs of newEntries to this map.
inherited
cast<RK, RV>() → Map<RK, RV>
Provides a view of this map as having RK keys and RV instances, if necessary.
inherited
clear() → void
Removes all entries from the map.
inherited
containsKey(Object? key) → bool
Whether this map contains the given key.
inherited
containsValue(Object? value) → bool
Whether this map contains the given value.
inherited
forEach(void action(int key, dynamic value)) → void
Applies action to each key/value pair of the map.
inherited
map<K2, V2>(MapEntry<K2, V2> transform(int key, dynamic value)) → Map<K2, V2>
Returns a new map where all entries of this map are transformed by the given convert function.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putIfAbsent(int key, dynamic ifAbsent()) → dynamic
Look up the value of key, or add a new entry if it isn't there.
inherited
remove(Object? key) → dynamic
Removes key and its associated value, if present, from the map.
inherited
removeWhere(bool test(int key, dynamic value)) → void
Removes all entries of this map that satisfy the given test.
inherited
toCbor() → CborValue
inherited
toCborMap() → CborMap
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited
update(int key, dynamic update(dynamic value), {dynamic ifAbsent()?}) → dynamic
Updates the value for the provided key.
inherited
updateAll(dynamic update(int key, dynamic value)) → void
Updates all values.
inherited
validate() → void
inherited
verify(List<int> message, List<int> signature, {SignatureEncoding? encoding, String? sm2Id, String mlDsaMode = 'pure', List<int> context = const []}) → Future<void>
Verifies a signature using the initialized Rust backend.
inherited
verifySync(List<int> message, List<int> signature, {SignatureEncoding? encoding, String? sm2Id, String mlDsaMode = 'pure', List<int> context = const []}) → void
ES256 defaults to WebAuthn DER; SM2 defaults to its explicit profile.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](Object? key) → dynamic
The value for the given key, or null if key is not in the map.
inherited
operator []=(int key, dynamic value) → void
Associates the key with the given value.
inherited

Static Methods

fromPublicKey(List<int> x, List<int> y, {required Sm2Configuration configuration}) → SM2