VerificationResult class

The result of a successful assertion (verification).

Annotations
  • @JsonSerializable.new(createFactory: false, explicitToJson: true)

Constructors

VerificationResult({required bool userPresent, required bool userVerified, required int signCount, required Uint8List authenticatorData})

Properties

authenticatorData Uint8List
Raw authenticator data bytes that were verified (optional but useful).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signCount int
Signature counter returned by the authenticator.
final
userPresent bool
Whether the authenticator reported the user was present (UP flag).
final
userVerified bool
Whether the authenticator reported the user was verified (UV flag).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited