ClientPinRequest class
CTAP2 authenticatorClientPIN (0x06) request (spec 6.5.5).
Used by platforms to perform key agreement, set/change a PIN, and obtain a pinUvAuthToken using a selected PIN/UV protocol.
- Annotations
-
- @JsonSerializable.new(createFactory: false, explicitToJson: true)
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyAgreement → CoseKey?
-
Platform key-agreement public key (COSE_Key) when required by subCommand.
final
-
newPinEnc
→ List<
int> ? -
Encrypted new PIN value.
final
- permissions → int?
-
Bitfield of permissions for the requested token.
final
-
pinHashEnc
→ List<
int> ? -
Encrypted proof-of-knowledge of the PIN.
final
-
pinUvAuthParam
→ List<
int> ? -
Authenticator input MAC parameter for subCommand contexts.
final
- pinUvAuthProtocol → int?
-
PIN/UV protocol version selected by the platform.
final
- rpId → String?
-
RP ID to bind to the permissions, if any.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subCommand → int
-
Specific subCommand to execute (e.g., getPINRetries, setPIN).
final
Methods
-
encode(
) → List< int> - Encodes this request as a CBOR map and prefixes the command byte.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- keyAgreementIdx → const int
- newPinEncIdx → const int
- permissionsIdx → const int
- pinHashEncIdx → const int
- pinUvAuthParamIdx → const int
- pinUvAuthProtocolIdx → const int
- rpIdIdx → const int
- subCommandIdx → const int