Sm2Configuration class
Explicit EC2 compatibility profile: SM2 has no IANA COSE allocation.
Constructors
- Sm2Configuration({required int algorithm, required int curve, String id = '1234567812345678', SignatureEncoding signatureEncoding = SignatureEncoding.raw, bool allowUnassignedIdentifiers = false})
Properties
- algorithm → int
-
final
- curve → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatureEncoding → SignatureEncoding
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited